library(ggplot2)
library(reshape2)
library(waffle) 
library(cowplot)  
library(tidyr)
library(dplyr)

#data preperation ----------------------------------------------------------------------
datacsv <- read.csv(file="./S5_2014-2018_summed_years_wheel_pass_SuppInfo.csv", 
        head=TRUE, sep=';', )
datacsv[datacsv<=0] <- NA

name_table <- vector()

for (j in 2:13){
   name_table[j-1] <- names(datacsv)[j]
   sum_table5 <-(round(sum(datacsv[datacsv[,1]<=5,][,j],na.rm=T)))
   sum_table10 <- round(sum(datacsv[datacsv[,1]<=10,][,j],na.rm=T)-sum_table5)
   sum_table15 <- round(sum(datacsv[datacsv[,1]<=15,][,j],na.rm=T)-(sum_table10+sum_table5))
   sum_table20 <- round(sum(datacsv[datacsv[,1]<=20,][,j],na.rm=T)-(sum_table10+sum_table5+sum_table15))
   sum_table30 <- round(sum(datacsv[datacsv[,1]<=30,][,j],na.rm=T)-(sum_table10+sum_table5+sum_table15+sum_table20))
   sum_table50 <- round(sum(datacsv[datacsv[,1]<=50,][,j],na.rm=T)-(sum_table10+sum_table5+sum_table15+sum_table20+sum_table30))
   sum_tableX <- round(sum(datacsv[datacsv[,1]>50,][,j],na.rm=T))
   sum_table0 <- round(100-round(sum(datacsv[,j],na.rm=T)))
   sum_table <- vector()
   sum_table <- c(sum_table0,sum_table5,sum_table10,sum_table15,sum_table20,sum_table30,sum_table50,sum_tableX) 
   if (j==2){
      sum_data_frame <- data.frame(sum_table)
      } else{
      sum_data_frame <- cbind(sum_data_frame,data.frame(sum_table))
      }
}

colnames(sum_data_frame)<- name_table
pass_labels <- c(0,5,10,15,20,30,50,100)
sum_data_frame <- cbind(sum_data_frame,data.frame("passes"=pass_labels))

rm(sum_table0,sum_table5,sum_table10,sum_table15,sum_table20,sum_table30,sum_table50,
   sum_tableX,sum_table,name_table,pass_labels)


#bar plots ------------------------------------------------------------------------------
# analyse all three years
data3 <- melt(sum_data_frame,id="passes")

y4 <- data3[grep('infield',data3[,2]),]
y4_headlands <- data3[grep('headland',data3[,2]),]
rm(data3)

y4 <- drop_na(y4)
y4_headlands <- drop_na(y4_headlands)

y4$year <- substr(y4$variable,2,10)  
y4_headlands$year <- substr(y4_headlands$variable,2,10)

legend_labels <- c("0","1 - 5","6 - 10","11 - 15","16 - 20","21 - 30","31 - 50","50+")

cols = c("#d9d9d9",'#bf812d','#dfc27d','#f6e8c3','#c7eae5','#80cdc1','#35978f','#01665e')

#############################################################################################################
########################-------------- geom_waffle chart for infield
waffle_infield <- ggplot(y4, aes(fill = passes, values = value)) +
  geom_waffle(color = "white", size = .25, n_rows = 5, flip = TRUE) +
  facet_wrap(~year, nrow = 1, strip.position = "bottom") +
  scale_x_discrete() + 
  scale_y_continuous(labels = function(x) x * 5, # make this multiplyer the same as n_rows
                     expand = c(0,0)) +
  scale_fill_manual(values=cols,labels=legend_labels)+
  coord_equal() +
  labs(
    subtitle = "in the crop zone"
  ) +
  theme_minimal()+
  theme(panel.grid = element_blank(), axis.ticks.y = element_line(),legend.position="none") +
  guides(fill = guide_legend(reverse = TRUE))

  ########################-------------- geom_waffle chart for headlands
# only to get the legend
waffle_head <- ggplot(y4_headlands, aes(fill = passes, values = value)) +
  geom_waffle(color = "white", size = .25, n_rows = 5, flip = TRUE) +
  facet_wrap(~year, nrow = 1, strip.position = "bottom") +
  scale_x_discrete() + 
  scale_y_continuous(labels = function(x) x * 5, 
                     expand = c(0,0)) +
  scale_fill_manual(values=cols,labels=legend_labels)+
  coord_equal() +
  labs(
    subtitle = "in the headland"
  ) +
  theme_minimal()+
  theme(panel.grid = element_blank(), axis.ticks.y = element_line()) +
  guides(fill = guide_legend(reverse = TRUE))

g_plot_legend <- get_legend(waffle_head) # get legend of waffle head

# for plotting
waffle_head <- ggplot(y4_headlands, aes(fill = passes, values = value)) +
  geom_waffle(color = "white", size = .25, n_rows = 5, flip = TRUE) +
  facet_wrap(~year, nrow = 1, strip.position = "bottom") +
  scale_x_discrete() + 
  scale_y_continuous(labels = function(x) x * 5, # make this multiplyer the same as n_rows
                     expand = c(0,0)) +
  scale_fill_manual(values=cols,labels=legend_labels)+
  coord_equal() +
  labs(
    subtitle = "in the headland"
  ) +
  theme_minimal()+
  theme(panel.grid = element_blank(), axis.ticks.y = element_line(),legend.position="none") +
  guides(fill = guide_legend(reverse = TRUE))
  
  
g_plot <- plot_grid(waffle_infield,waffle_head,g_plot_legend,
       ncol=3, rel_widths=c(4,4,1)
       )
g_plot 

g_plot2 <- ggdraw(g_plot)+
  draw_plot_label("Percentage of area covered by classes of wheel-pass-frequency", x=0,y=1, size = 12, fontface="bold", hjus=-0.1, vjus=1.5)
g_plot2                     


ggsave("wheel_passes_cumulative.pdf",g_plot,width=40, height=20, units='cm',dpi=600)

